summaryrefslogtreecommitdiff
path: root/src/game/bg_public.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/bg_public.h')
-rw-r--r--src/game/bg_public.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/game/bg_public.h b/src/game/bg_public.h
index 64ce615..e06015d 100644
--- a/src/game/bg_public.h
+++ b/src/game/bg_public.h
@@ -233,8 +233,9 @@ typedef enum
STAT_BUILDABLE, // which ghost model to display for building
STAT_FALLDIST, // the distance the player fell
STAT_VIEWLOCK, // direction to lock the view in
- STAT_FUEL // jetpacks
- // netcode has space for 2 more
+ STAT_FUEL, // jetpacks
+ STAT_SHAKE // camera shake
+ // netcode has space for 1 more
} statIndex_t;
#define SCA_WALLCLIMBER 0x00000001
@@ -397,6 +398,8 @@ typedef enum
UP_BIORES,
UP_AMMO,
+
+ UP_NIGHTVISION, // aliens
UP_NUM_UPGRADES
} upgrade_t;
@@ -630,6 +633,7 @@ typedef enum
MN_B_CUBOID_MODE1,
MN_B_CUBOID_MODE2,
MN_B_TOODENSE,
+ MN_B_INVALIDSIZE,
//alien build
MN_A_ONEOVERMIND,